[tip:core/locking] ASoC: multi-component - Add Goni sound driver

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Commit-ID:  f51582fd8d9b1196d58cd94c2b4b759cc1baf57a
Gitweb:     http://git.kernel.org/tip/f51582fd8d9b1196d58cd94c2b4b759cc1baf57a
Author:     Chanwoo Choi <cw00.choi@xxxxxxxxxxx>
AuthorDate: Thu, 22 Jul 2010 15:16:10 +0900
Committer:  Liam Girdwood <lrg@xxxxxxxxxxxxxxx>
CommitDate: Thu, 12 Aug 2010 14:00:15 +0100

ASoC: multi-component - Add Goni sound driver

This patch add sound support for the Goni board based on S5PV210.

The Goni board is based on Samsung SoC(S5PV210) and include
WM8994 codec over I2S to support sound.

The kind of jack is below states :
* SND_JACK_HEADPHONE
* SND_JACK_HEADSET
* SND_JACK_MECHANICAL
  : When TV-OUT cable is inserted on Goni board,
  the TV-OUT cable isn't connected to television.
* SND_JACK_AVOUT
  : When TV-OUT cable is inserted on Goni board,
  the TV-OUT cable is connected to television.

Signed-off-by: Chanwoo Choi <cw00.choi@xxxxxxxxxxx>
Signed-off-by: Joonyoung Shim <jy0922.shim@xxxxxxxxxxx>
Signed-off-by: Kyungmin Park <kyungmin.park@xxxxxxxxxxx>
Acked-by: Mark Brown <broonie@xxxxxxxxxxxxxxxxxxxxxxxxxxx>
Signed-off-by: Liam Girdwood <lrg@xxxxxxxxxxxxxxx>
---
 sound/soc/s3c24xx/Kconfig                          |    9 ++
 sound/soc/s3c24xx/Makefile                         |    2 +
 .../soc/s3c24xx/{aquila_wm8994.c => goni_wm8994.c} |   97 ++++++++++----------
 3 files changed, 61 insertions(+), 47 deletions(-)

diff --git a/sound/soc/s3c24xx/Kconfig b/sound/soc/s3c24xx/Kconfig
index c09b402..1cdc37bd 100644
--- a/sound/soc/s3c24xx/Kconfig
+++ b/sound/soc/s3c24xx/Kconfig
@@ -140,3 +140,12 @@ config SND_S5PC110_SOC_AQUILA_WM8994
 	help
 	  Say Y if you want to add support for SoC audio on aquila
 	  with the WM8994.
+
+config SND_S5PV210_SOC_GONI_WM8994
+	tristate "SoC I2S Audio support for GONI - WM8994"
+	depends on SND_S3C24XX_SOC && MACH_GONI
+	select SND_S3C64XX_SOC_I2S_V4
+	select SND_SOC_WM8994
+	help
+	  Say Y if you want to add support for SoC audio on goni
+	  with the WM8994.
diff --git a/sound/soc/s3c24xx/Makefile b/sound/soc/s3c24xx/Makefile
index 02dd12c..47ed6d7 100644
--- a/sound/soc/s3c24xx/Makefile
+++ b/sound/soc/s3c24xx/Makefile
@@ -31,6 +31,7 @@ snd-soc-smdk64xx-wm8580-objs := smdk64xx_wm8580.o
 snd-soc-smdk-wm9713-objs := smdk_wm9713.o
 snd-soc-s3c64xx-smartq-wm8987-objs := smartq_wm8987.o
 snd-soc-aquila-wm8994-objs := aquila_wm8994.o
+snd-soc-goni-wm8994-objs := goni_wm8994.o
 
 obj-$(CONFIG_SND_S3C24XX_SOC_JIVE_WM8750) += snd-soc-jive-wm8750.o
 obj-$(CONFIG_SND_S3C24XX_SOC_NEO1973_WM8753) += snd-soc-neo1973-wm8753.o
@@ -45,3 +46,4 @@ obj-$(CONFIG_SND_S3C64XX_SOC_WM8580) += snd-soc-smdk64xx-wm8580.o
 obj-$(CONFIG_SND_SOC_SMDK_WM9713) += snd-soc-smdk-wm9713.o
 obj-$(CONFIG_SND_S3C64XX_SOC_SMARTQ) += snd-soc-s3c64xx-smartq-wm8987.o
 obj-$(CONFIG_SND_S5PC110_SOC_AQUILA_WM8994) += snd-soc-aquila-wm8994.o
+obj-$(CONFIG_SND_S5PV210_SOC_GONI_WM8994) += snd-soc-goni-wm8994.o
diff --git a/sound/soc/s3c24xx/aquila_wm8994.c b/sound/soc/s3c24xx/goni_wm8994.c
similarity index 73%
copy from sound/soc/s3c24xx/aquila_wm8994.c
copy to sound/soc/s3c24xx/goni_wm8994.c
index 235d197..694f702 100644
--- a/sound/soc/s3c24xx/aquila_wm8994.c
+++ b/sound/soc/s3c24xx/goni_wm8994.c
@@ -1,5 +1,5 @@
 /*
- * aquila_wm8994.c
+ * goni_wm8994.c
  *
  * Copyright (C) 2010 Samsung Electronics Co.Ltd
  * Author: Chanwoo Choi <cw00.choi@xxxxxxxxxxx>
@@ -28,8 +28,8 @@
 #include "s3c-dma.h"
 #include "s3c64xx-i2s.h"
 
-static struct snd_soc_card aquila;
-static struct platform_device *aquila_snd_device;
+static struct snd_soc_card goni;
+static struct platform_device *goni_snd_device;
 
 /* 3.5 pie jack */
 static struct snd_soc_jack jack;
@@ -57,8 +57,9 @@ static struct snd_soc_jack_gpio jack_gpios[] = {
 	},
 };
 
-static const struct snd_soc_dapm_widget aquila_dapm_widgets[] = {
-	SND_SOC_DAPM_SPK("Ext Spk", NULL),
+static const struct snd_soc_dapm_widget goni_dapm_widgets[] = {
+	SND_SOC_DAPM_SPK("Ext Left Spk", NULL),
+	SND_SOC_DAPM_SPK("Ext Right Spk", NULL),
 	SND_SOC_DAPM_SPK("Ext Rcv", NULL),
 	SND_SOC_DAPM_HP("Headset Stereophone", NULL),
 	SND_SOC_DAPM_MIC("Headset Mic", NULL),
@@ -67,9 +68,12 @@ static const struct snd_soc_dapm_widget aquila_dapm_widgets[] = {
 	SND_SOC_DAPM_LINE("Radio In", NULL),
 };
 
-static const struct snd_soc_dapm_route aquila_dapm_routes[] = {
-	{"Ext Spk", NULL, "SPKOUTLP"},
-	{"Ext Spk", NULL, "SPKOUTLN"},
+static const struct snd_soc_dapm_route goni_dapm_routes[] = {
+	{"Ext Left Spk", NULL, "SPKOUTLP"},
+	{"Ext Left Spk", NULL, "SPKOUTLN"},
+
+	{"Ext Right Spk", NULL, "SPKOUTRP"},
+	{"Ext Right Spk", NULL, "SPKOUTRN"},
 
 	{"Ext Rcv", NULL, "HPOUT2N"},
 	{"Ext Rcv", NULL, "HPOUT2P"},
@@ -90,18 +94,18 @@ static const struct snd_soc_dapm_route aquila_dapm_routes[] = {
 	{"IN2RN", NULL, "Radio In"},
 };
 
-static int aquila_wm8994_init(struct snd_soc_pcm_runtime *rtd)
+static int goni_wm8994_init(struct snd_soc_pcm_runtime *rtd)
 {
 	struct snd_soc_codec *codec = rtd->codec;
 	int ret;
 
-	/* add aquila specific widgets */
-	snd_soc_dapm_new_controls(codec, aquila_dapm_widgets,
-			ARRAY_SIZE(aquila_dapm_widgets));
+	/* add goni specific widgets */
+	snd_soc_dapm_new_controls(codec, goni_dapm_widgets,
+			ARRAY_SIZE(goni_dapm_widgets));
 
-	/* set up aquila specific audio routes */
-	snd_soc_dapm_add_routes(codec, aquila_dapm_routes,
-			ARRAY_SIZE(aquila_dapm_routes));
+	/* set up goni specific audio routes */
+	snd_soc_dapm_add_routes(codec, goni_dapm_routes,
+			ARRAY_SIZE(goni_dapm_routes));
 
 	/* set endpoints to not connected */
 	snd_soc_dapm_nc_pin(codec, "IN2LP:VXRN");
@@ -110,13 +114,11 @@ static int aquila_wm8994_init(struct snd_soc_pcm_runtime *rtd)
 	snd_soc_dapm_nc_pin(codec, "LINEOUT1P");
 	snd_soc_dapm_nc_pin(codec, "LINEOUT2N");
 	snd_soc_dapm_nc_pin(codec, "LINEOUT2P");
-	snd_soc_dapm_nc_pin(codec, "SPKOUTRN");
-	snd_soc_dapm_nc_pin(codec, "SPKOUTRP");
 
 	snd_soc_dapm_sync(codec);
 
 	/* Headset jack detection */
-	ret = snd_soc_jack_new(&aquila, "Headset Jack",
+	ret = snd_soc_jack_new(&goni, "Headset Jack",
 			SND_JACK_HEADSET | SND_JACK_MECHANICAL | SND_JACK_AVOUT,
 			&jack);
 	if (ret)
@@ -133,7 +135,7 @@ static int aquila_wm8994_init(struct snd_soc_pcm_runtime *rtd)
 	return 0;
 }
 
-static int aquila_hifi_hw_params(struct snd_pcm_substream *substream,
+static int goni_hifi_hw_params(struct snd_pcm_substream *substream,
 		struct snd_pcm_hw_params *params)
 {
 	struct snd_soc_pcm_runtime *rtd = substream->private_data;
@@ -175,11 +177,11 @@ static int aquila_hifi_hw_params(struct snd_pcm_substream *substream,
 	return 0;
 }
 
-static struct snd_soc_ops aquila_hifi_ops = {
-	.hw_params = aquila_hifi_hw_params,
+static struct snd_soc_ops goni_hifi_ops = {
+	.hw_params = goni_hifi_hw_params,
 };
 
-static int aquila_voice_hw_params(struct snd_pcm_substream *substream,
+static int goni_voice_hw_params(struct snd_pcm_substream *substream,
 		struct snd_pcm_hw_params *params)
 {
 	struct snd_soc_pcm_runtime *rtd = substream->private_data;
@@ -212,7 +214,8 @@ static int aquila_voice_hw_params(struct snd_pcm_substream *substream,
 }
 
 static struct snd_soc_dai_driver voice_dai = {
-	.name = "aquila-voice-dai",
+	.name = "goni-voice-dai",
+	.id = 0,
 	.playback = {
 		.channels_min = 1,
 		.channels_max = 2,
@@ -225,11 +228,11 @@ static struct snd_soc_dai_driver voice_dai = {
 		.formats = SNDRV_PCM_FMTBIT_S16_LE,},
 };
 
-static struct snd_soc_ops aquila_voice_ops = {
-	.hw_params = aquila_voice_hw_params,
+static struct snd_soc_ops goni_voice_ops = {
+	.hw_params = goni_voice_hw_params,
 };
 
-static struct snd_soc_dai_link aquila_dai[] = {
+static struct snd_soc_dai_link goni_dai[] = {
 {
 	.name = "WM8994",
 	.stream_name = "WM8994 HiFi",
@@ -237,59 +240,59 @@ static struct snd_soc_dai_link aquila_dai[] = {
 	.codec_dai_name = "wm8994-hifi",
 	.platform_name = "s3c24xx-pcm-audio",
 	.codec_name = "wm8994-codec.0-0x1a",
-	.init = aquila_wm8994_init,
-	.ops = &aquila_hifi_ops,
+	.init = goni_wm8994_init,
+	.ops = &goni_hifi_ops,
 }, {
 	.name = "WM8994 Voice",
 	.stream_name = "Voice",
-	.cpu_dai_name = "aquila-voice-dai",
+	.cpu_dai_name = "goni-voice-dai",
 	.codec_dai_name = "wm8994-voice",
 	.platform_name = "s3c24xx-pcm-audio",
 	.codec_name = "wm8994-codec.0-0x1a",
-	.ops = &aquila_voice_ops,
+	.ops = &goni_voice_ops,
 },
 };
 
-static struct snd_soc_card aquila = {
-	.name = "aquila",
-	.dai_link = aquila_dai,
-	.num_links = ARRAY_SIZE(aquila_dai),
+static struct snd_soc_card goni = {
+	.name = "goni",
+	.dai_link = goni_dai,
+	.num_links = ARRAY_SIZE(goni_dai),
 };
 
-static int __init aquila_init(void)
+static int __init goni_init(void)
 {
 	int ret;
 
-	if (!machine_is_aquila())
+	if (!machine_is_goni())
 		return -ENODEV;
 
-	aquila_snd_device = platform_device_alloc("soc-audio", -1);
-	if (!aquila_snd_device)
+	goni_snd_device = platform_device_alloc("soc-audio", -1);
+	if (!goni_snd_device)
 		return -ENOMEM;
 
 	/* register voice DAI here */
-	ret = snd_soc_register_dai(&aquila_snd_device->dev, &voice_dai);
+	ret = snd_soc_register_dai(&goni_snd_device->dev, &voice_dai);
 	if (ret)
 		return ret;
 
-	platform_set_drvdata(aquila_snd_device, &aquila);
-	ret = platform_device_add(aquila_snd_device);
+	platform_set_drvdata(goni_snd_device, &goni);
+	ret = platform_device_add(goni_snd_device);
 
 	if (ret)
-		platform_device_put(aquila_snd_device);
+		platform_device_put(goni_snd_device);
 
 	return ret;
 }
 
-static void __exit aquila_exit(void)
+static void __exit goni_exit(void)
 {
-	platform_device_unregister(aquila_snd_device);
+	platform_device_unregister(goni_snd_device);
 }
 
-module_init(aquila_init);
-module_exit(aquila_exit);
+module_init(goni_init);
+module_exit(goni_exit);
 
 /* Module information */
-MODULE_DESCRIPTION("ALSA SoC WM8994 Aquila(S5PC110)");
+MODULE_DESCRIPTION("ALSA SoC WM8994 GONI(S5PV210)");
 MODULE_AUTHOR("Chanwoo Choi <cw00.choi@xxxxxxxxxxx>");
 MODULE_LICENSE("GPL");
--
To unsubscribe from this list: send the line "unsubscribe linux-tip-commits" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[Index of Archives]     [Linux Stable Commits]     [Linux Stable Kernel]     [Linux Kernel]     [Linux USB Devel]     [Linux Video &Media]     [Linux Audio Users]     [Yosemite News]     [Linux SCSI]

  Powered by Linux